# -*- coding: utf-8 -*-
'''
Views for CAPAKEY services.

.. versionadded:: 0.1.0
'''
from pyramid.view import view_config
from crabpy_pyramid.utils import range_return

@view_config(route_name='list_gemeenten', renderer='capakey_listjson', accept='application/json')
def list_gemeenten(request):
    Gateway = request.capakey_gateway()
    gemeenten = Gateway.list_gemeenten(1)
    return range_return(request, gemeenten)


@view_config(route_name='get_gemeente', renderer='capakey_itemjson', accept='application/json')
def get_gemeente_by_niscode(request):
    Gateway = request.capakey_gateway()
    gemeente_id = int(request.matchdict.get('gemeente_id'))
    return Gateway.get_gemeente_by_id(gemeente_id)


@view_config(
    route_name='list_kadastrale_afdelingen_by_gemeente',
    renderer='capakey_listjson', accept='application/json'
)
def list_kadastrale_afdelingen_by_gemeente(request):
    Gateway = request.capakey_gateway()
    gemeente_id = request.matchdict.get('gemeente_id')
    afdelingen = Gateway.list_kadastrale_afdelingen_by_gemeente(gemeente_id)
    return range_return(request, afdelingen)


@view_config(route_name='list_kadastrale_afdelingen', renderer='capakey_listjson', accept='application/json')
def list_kadastrale_afdelingen(request):
    Gateway = request.capakey_gateway()
    afdelingen = Gateway.list_kadastrale_afdelingen()
    return range_return(request, afdelingen)


@view_config(
    route_name='get_kadastrale_afdeling_by_id',
    renderer='capakey_itemjson', accept='application/json'
)
def get_kadastrale_afdeling_by_id(request):
    Gateway = request.capakey_gateway()
    afdeling_id = request.matchdict.get('afdeling_id')
    return Gateway.get_kadastrale_afdeling_by_id(afdeling_id)


@view_config(
    route_name='list_secties_by_afdeling',
    renderer='capakey_listjson', accept='application/json'
)
def list_secties_by_afdeling(request):
    Gateway = request.capakey_gateway()
    afdeling_id = request.matchdict.get('afdeling_id')
    secties = Gateway.list_secties_by_afdeling(afdeling_id)
    return range_return(request, secties)


@view_config(
    route_name='get_sectie_by_id_and_afdeling',
    renderer='capakey_itemjson', accept='application/json'
)
def get_sectie_by_id_and_afdeling(request):
    Gateway = request.capakey_gateway()
    afdeling_id = request.matchdict.get('afdeling_id')
    sectie_id = request.matchdict.get('sectie_id')
    return Gateway.get_sectie_by_id_and_afdeling(sectie_id, afdeling_id)


@view_config(
    route_name='list_percelen_by_sectie',
    renderer='capakey_listjson', accept='application/json'
)
def list_percelen_by_sectie(request):
    Gateway = request.capakey_gateway()
    sectie_id = request.matchdict.get('sectie_id')
    afdeling_id = request.matchdict.get('afdeling_id')
    sectie = Gateway.get_sectie_by_id_and_afdeling(sectie_id, afdeling_id)
    percelen = Gateway.list_percelen_by_sectie(sectie)
    return range_return(request, percelen)


@view_config(
    route_name='get_perceel_by_sectie_and_id',
    renderer='capakey_itemjson', accept='application/json'
)
def get_perceel_by_sectie_and_id(request):
    Gateway = request.capakey_gateway()
    perceel_id = str(request.matchdict.get('perceel_id1'))+'/'\
        + str(request.matchdict.get('perceel_id2'))
    sectie_id = request.matchdict.get('sectie_id')
    afdeling_id = request.matchdict.get('afdeling_id')
    sectie = Gateway.get_sectie_by_id_and_afdeling(sectie_id, afdeling_id)
    return Gateway.get_perceel_by_id_and_sectie(perceel_id, sectie)


@view_config(
    route_name='get_perceel_by_capakey',
    renderer='capakey_itemjson', accept='application/json'
)
def get_perceel_by_capakey(request):
    Gateway = request.capakey_gateway()
    capakey = str(request.matchdict.get('capakey1'))+'/'\
        + str(request.matchdict.get('capakey2'))
    return Gateway.get_perceel_by_capakey(capakey)


@view_config(
    route_name='get_perceel_by_percid',
    renderer='capakey_itemjson', accept='application/json'
)
def get_perceel_by_percid(request):
    Gateway = request.capakey_gateway()
    percid = request.matchdict.get('percid')
    return Gateway.get_perceel_by_percid(percid)



# -*- coding: utf-8 -*-
'''
Routes for the CAPAKEY views.

.. versionadded:: 0.1.0
'''
def includeme(config):
    config.add_route('list_gemeenten', '/capakey/gemeenten')
    config.add_route('get_gemeente', '/capakey/gemeenten/{gemeente_id}')
    config.add_route(
        'list_kadastrale_afdelingen_by_gemeente',
        '/capakey/gemeenten/{gemeente_id}/afdelingen'
    )
    config.add_route('list_kadastrale_afdelingen', '/capakey/afdelingen')
    config.add_route(
        'get_kadastrale_afdeling_by_id',
        '/capakey/afdelingen/{afdeling_id}'
    )
    config.add_route(
        'list_secties_by_afdeling',
        '/capakey/afdelingen/{afdeling_id}/secties'
    )
    config.add_route(   
        'get_sectie_by_id_and_afdeling',
        '/capakey/afdelingen/{afdeling_id}/secties/{sectie_id}'
    )
    config.add_route(
        'list_percelen_by_sectie',
        '/capakey/afdelingen/{afdeling_id}/secties/{sectie_id}/percelen'
    )
    config.add_route(
        'get_perceel_by_sectie_and_id',
        '/capakey/afdelingen/{afdeling_id}/secties/{sectie_id}/percelen/{perceel_id1}/{perceel_id2}'
    )
    config.add_route(
        'get_perceel_by_capakey',
        '/capakey/percelen/{capakey1}/{capakey2}'
    )
    config.add_route(
        'get_perceel_by_percid',
        '/capakey/percelen/{percid}'
    )



# -*- coding: utf-8 -*-
'''
Utility functions to help with range handling.

.. versionadded:: 0.1.0
'''

import re

MAX_NUMBER_ITEMS = 5000

def parse_range_header(range):
    '''
    Parse a range header as used by the dojo Json Rest store.

    :param str range: The content of the range header to be parsed. 
        eg. `items=0-9`
    :returns: A dict with keys start, finish and number or `False` if the
        range is invalid.
    '''
    match = re.match('^items=([0-9]+)-([0-9]+)$', range)

    if match:
        start = int(match.group(1))
        finish = int(match.group(2))

        if finish < start:
            finish = start
        return {
            'start': start,
            'finish': finish,
            'count': finish - start + 1
        }
    else:
        return False

def range_return(request, items):
    '''
    Determine what range of objects to return.

    Will check fot both `Range` and `X-Range` headers in the request and
    set both `Content-Range` and 'X-Content-Range' headers.

    :rtype: list
    '''
    if ('Range' in request.headers):
        range = parse_range_header(request.headers['Range'])
    elif 'X-Range' in request.headers:
        range = parse_range_header(request.headers['X-Range'])
    else:
        range = {
            'start': 0,
            'finish': MAX_NUMBER_ITEMS - 1,
            'count': MAX_NUMBER_ITEMS
        }
    filtered = items[range['start']:range['count']]
    if len(filtered) < range['count']:
        # Something was stripped, deal with it
        range['count'] = len(filtered)
        range['finish'] = range['start'] + range['count'] - 1

    request.response.headers['Content-Range'] = 'items %d-%d/%d' % (range['start'], range['finish'], len(items))
    request.response.headers['X-Content-Range'] = request.response.headers['Content-Range']
    return filtered



# -*- coding: utf-8 -*-
'''
Views for CRAB services

.. versionadded:: 0.1.0
'''
from pyramid.view import view_config
from crabpy_pyramid.utils import range_return


@view_config(
    route_name='list_gewesten',
    renderer='crab_listjson', accept='application/json'
)
def list_gewesten(request):
    Gateway = request.crab_gateway()
    gewesten = Gateway.list_gewesten()
    return range_return(request, gewesten)

@view_config(
    route_name='get_gewest_by_id',
    renderer='crab_itemjson', accept='application/json'
)
def get_gewest_by_id(request):
    Gateway = request.crab_gateway()
    gewest_id = int(request.matchdict.get('gewest_id'))
    return Gateway.get_gewest_by_id(gewest_id)
    
@view_config(
    route_name='list_provincies',
    renderer='crab_listjson', accept='application/json'
)
def list_provincies(request):
    Gateway = request.crab_gateway()
    gewest_id = int(request.matchdict.get('gewest_id'))
    provincies = Gateway.list_provincies(gewest_id)
    return range_return(request, provincies)
    
@view_config(
    route_name='get_provincie',
    renderer='crab_itemjson', accept='application/json'
)
def get_provincie(request):
    Gateway = request.crab_gateway()
    provincie_id = int(request.matchdict.get('provincie_id'))
    provincie = Gateway.get_provincie_by_id(provincie_id)
    return provincie
    
@view_config(
    route_name='list_gemeenten_by_provincie',
    renderer='crab_listjson', accept='application/json'
)
def list_gemeenten_by_provincie(request):
    Gateway = request.crab_gateway()
    provincie_id = int(request.matchdict.get('provincie_id'))
    gemeenten = Gateway.list_gemeenten_by_provincie(provincie_id)
    return range_return(request, gemeenten)
    
@view_config(
    route_name='list_gemeenten_crab',
    renderer='crab_listjson', accept='application/json'
)
def list_gemeenten_crab(request):
    Gateway = request.crab_gateway()
    sort = request.params.get('sort', 'niscode')
    sort_map = {'id': 1, 'naam': 2, 'niscode': 6}
    sort = sort_map.get(sort, 6)
    gewest_id = request.matchdict.get('gewest_id')
    gemeenten = Gateway.list_gemeenten(gewest_id, sort)
    return range_return(request, gemeenten)

@view_config(
    route_name='get_gemeente_crab',
    renderer='crab_itemjson', accept='application/json'
)
def get_gemeente_crab(request):
    Gateway = request.crab_gateway()
    gemeente_id = request.matchdict.get('gemeente_id')
    if len(gemeente_id) == 5:
        return Gateway.get_gemeente_by_niscode(gemeente_id)
    else:
        return Gateway.get_gemeente_by_id(gemeente_id)

@view_config(
    route_name='list_straten',
    renderer='crab_listjson', accept='application/json'
)
def list_straten(request):
    Gateway = request.crab_gateway()
    gemeente_id = request.matchdict.get('gemeente_id')
    if len(gemeente_id)==5:
        gemeente_id = Gateway.get_gemeente_by_niscode(gemeente_id)
    straten = Gateway.list_straten(gemeente_id)
    return range_return(request, straten)

@view_config(
    route_name='get_straat_by_id',
    renderer='crab_itemjson', accept='application/json'
)
def get_straat_by_id(request):
    Gateway = request.crab_gateway()
    straat_id = request.matchdict.get('straat_id')
    return Gateway.get_straat_by_id(straat_id)

@view_config(
    route_name='list_huisnummers',
    renderer='crab_listjson', accept='application/json'
)
def list_huisnummers(request):
    Gateway = request.crab_gateway()
    straat_id = request.matchdict.get('straat_id')
    huisnummers = Gateway.list_huisnummers_by_straat(straat_id)
    return range_return(request, huisnummers)

@view_config(
    route_name='get_huisnummer_by_straat_and_label',
    renderer='crab_itemjson', accept='application/json'
)
def get_huisnummer_by_straat_and_label(request):
    Gateway = request.crab_gateway()
    straat_id = request.matchdict.get('straat_id')
    huisnummer = request.matchdict.get('huisnummer_label')
    return Gateway.get_huisnummer_by_nummer_and_straat(huisnummer, straat_id)
    
    
@view_config(
    route_name='get_huisnummer_by_id',
    renderer='crab_itemjson', accept='application/json'
)
def get_huisnummer_by_id(request):
    Gateway = request.crab_gateway()
    huisnummer_id = request.matchdict.get('huisnummer_id')
    return Gateway.get_huisnummer_by_id(huisnummer_id)

@view_config(
    route_name='list_percelen',
    renderer='crab_listjson', accept='application/json'
)
def list_percelen(request):
    Gateway = request.crab_gateway()
    huisnummer_id = request.matchdict.get('huisnummer_id')
    percelen = Gateway.list_percelen_by_huisnummer(huisnummer_id)
    return range_return(request, percelen)

@view_config(
    route_name='get_perceel_by_id',
    renderer='crab_itemjson', accept='application/json'
)
def get_perceel_by_id(request):
    Gateway = request.crab_gateway()
    perceel_id = request.matchdict.get('perceel_id1')+'/'+request.matchdict.get('perceel_id2')
    return Gateway.get_perceel_by_id(perceel_id)

@view_config(
    route_name='list_gebouwen',
    renderer='crab_listjson', accept='application/json'
)
def list_gebouwen(request):
    Gateway = request.crab_gateway()
    huisnummer_id = request.matchdict.get('huisnummer_id')
    gebouwen = Gateway.list_gebouwen_by_huisnummer(huisnummer_id)
    return range_return(request, gebouwen)

@view_config(
    route_name='get_gebouw_by_id',
    renderer='crab_itemjson', accept='application/json'
)
def get_gebouw_by_id(request):
    Gateway = request.crab_gateway()
    gebouw_id = request.matchdict.get('gebouw_id')
    return Gateway.get_gebouw_by_id(gebouw_id)
    
@view_config(
    route_name='get_wegobject',
    renderer='crab_itemjson', accept='application/json'
)
def get_wegobject(request):
    Gateway = request.crab_gateway()
    wegobject_id = request.matchdict.get('wegobject_id')
    return Gateway.get_wegobject_by_id(wegobject_id)



# -*- coding: utf-8 -*-

import logging
log = logging.getLogger(__name__)

from pyramid.config import Configurator
import os
import warnings
from dogpile.cache import make_region

from crabpy.gateway.capakey import CapakeyGateway
from crabpy.gateway.crab import CrabGateway
from crabpy.client import capakey_factory, crab_factory
from zope.interface import Interface

from crabpy_pyramid.renderers.capakey import (
    json_list_renderer as capakey_json_list_renderer,
    json_item_renderer as capakey_json_item_renderer
)

from crabpy_pyramid.renderers.crab import (
    json_list_renderer as crab_json_list_renderer,
    json_item_renderer as crab_json_item_renderer
)

from pyramid.settings import asbool

import logging
log = logging.getLogger(__name__)

class ICapakey(Interface):
    pass


class ICrab(Interface):
    pass


def _parse_settings(settings):
    args = {}
    defaults = {
        'capakey.include' : False,
        'crab.include' : True,
        'cache.file.root': '/tmp/dogpile_data'
    }
    args = defaults.copy()

    # booelean settings
    for short_key_name in ('capakey.include', 'crab.include'):
        key_name = "crabpy.%s" % (short_key_name)
        if key_name in settings:
            args[short_key_name] = asbool(settings.get(
                key_name, defaults.get(short_key_name)
            ))

    # set settings
    for short_key_name in ('capakey.user', 'capakey.password'):
        key_name = "crabpy.%s" % (short_key_name)
        if key_name in settings:
            args[short_key_name] = settings.get(
                key_name, defaults.get(short_key_name)
            )
    # string setting
    for short_key_name in ('proxy.http', 'proxy.https', 'cache.file.root'):
        key_name = "crabpy.%s" % (short_key_name)
        if key_name in settings:
            args[short_key_name] = settings.get(key_name)

    # cache configuration
    for short_key_name in ('crab.cache_config', 'capakey.cache_config'):
        key_name = "crabpy.%s." % (short_key_name)
        cache_config = {}
        for skey in settings.keys():
            if skey.startswith(key_name):
                cache_config[skey[len(key_name):]] = settings.get(skey)
        if cache_config:
            args[short_key_name] = cache_config
    
    log.debug(args) 
    return args

def _filter_settings(settings, prefix):
    """
    Filter all settings to only return settings that start with a certain 
    prefix.

    :param dict settings: A settings dictionary.
    :param str prefix: A prefix.
    """
    ret = {}
    for skey in settings.keys():
        if skey.startswith(prefix):
            key = skey[len(prefix):]
            ret[key] = settings[skey]
    return ret

def _build_capakey(registry, settings):
    capakey = registry.queryUtility(ICapakey)
    if capakey is not None:
        return capakey
    if 'cache_config' in settings:
        cache_config = settings['cache_config']
        del settings['cache_config']
    else:
        cache_config = {}
    factory = capakey_factory(**settings)
    gateway = CapakeyGateway(factory, cache_config=cache_config)

    registry.registerUtility(gateway, ICapakey)
    return registry.queryUtility(ICapakey)


def _build_crab(registry, settings):
    crab = registry.queryUtility(ICrab)
    if crab is not None:
        return crab
    if 'cache_config' in settings:
        cache_config = settings['cache_config']
        del settings['cache_config']
    else:
        cache_config = {}
    factory = crab_factory(**settings)
    gateway = CrabGateway(factory, cache_config=cache_config)
    
    registry.registerUtility(gateway, ICrab)
    return registry.queryUtility(ICapakey)


def get_capakey(registry):
    '''
    Get the Capakey Gateway

    :rtype: :class:`crabpy.gateway.capakey.CapakeyGateway`
    '''
    #argument might be a config or a request
    regis = getattr(registry, 'registry', None)
    if regis is None:
        regis = registry

    return regis.queryUtility(ICapakey)
    
def get_crab(registry):
    '''
    Get the Crab Gateway

    :rtype: :class:`crabpy.gateway.crab.CrabGateway`
    '''
    #argument might be a config or a request
    regis = getattr(registry, 'registry', None)
    if regis is None:
        regis = registry
        
    return regis.queryUtility(ICrab)

def _get_proxy_settings(settings):
    base_settings = {}
    if "proxy.http" or "proxy.https" in settings:
        base_settings["proxy"] = {}
        if "proxy.http" in settings:
            base_settings["proxy"]["http"] = settings["proxy.http"]
        if "proxy.https" in settings:
            base_settings["proxy"]["https"] = settings["proxy.https"]
    return base_settings

def includeme(config):
    '''
    Include `crabpy_pyramid` in this `Pyramid` application.

    :param pyramid.config.Configurator config: A Pyramid configurator.
    '''

    settings = _parse_settings(config.registry.settings)
    base_settings = _get_proxy_settings(settings)

    # create cache
    root = settings.get('cache.file.root', '/tmp/dogpile_data')
    if not os.path.exists(root):
        os.makedirs(root)

    capakey_settings = dict(_filter_settings(settings, 'capakey.'), **base_settings)
    if capakey_settings['include']:
        log.info('Adding CAPAKEY Gateway.')
        del capakey_settings['include']
        if not 'user' in capakey_settings or not 'password' in capakey_settings:
            warnings.warn(
                'capakey.user or capakey.password was not found in \
                the settings, capakey needs this parameter to \
                function properly.',
                UserWarning
            )
        else:    
            config.add_renderer('capakey_listjson', capakey_json_list_renderer)
            config.add_renderer('capakey_itemjson', capakey_json_item_renderer)
            _build_capakey(config.registry, capakey_settings)
            config.add_request_method(get_capakey, 'capakey_gateway')
            config.add_directive('get_capakey', get_capakey)
            config.include('crabpy_pyramid.routes.capakey')
            config.scan('crabpy_pyramid.views.capakey')
    
    crab_settings = dict(_filter_settings(settings, 'crab.'), **base_settings)
    if crab_settings['include']:
        log.info('Adding CRAB Gateway.')
        del crab_settings['include']
        config.add_renderer('crab_listjson', crab_json_list_renderer)
        config.add_renderer('crab_itemjson', crab_json_item_renderer)
        _build_crab(config.registry, crab_settings)
        config.add_directive('get_crab', get_crab)
        config.add_request_method(get_crab, 'crab_gateway')
        config.include('crabpy_pyramid.routes.crab')
        config.scan('crabpy_pyramid.views.crab')


def main(global_config, **settings):
    '''
     This function returns a Pyramid WSGI application.
    '''
    config = Configurator(settings=settings)
    
    includeme(config)
    return config.make_wsgi_app()



# -*- coding: utf-8 -*-
'''
including all the route information
.. versionadded:: 0.1.0
'''
def includeme(config):
    config.add_route('list_gemeenten', '/capakey/gemeenten')
    config.add_route('get_gemeente', '/capakey/gemeenten/{gemeente_id}')
    config.add_route(
        'list_kadastrale_afdelingen_by_gemeente',
        '/capakey/gemeenten/{gemeente_id}/afdelingen'
    )
    config.add_route('list_kadastrale_afdelingen', '/capakey/afdelingen')
    config.add_route(
        'get_kadastrale_afdeling_by_id',
        '/capakey/afdelingen/{afdeling_id}'
    )
    config.add_route(
        'list_secties_by_afdeling',
        '/capakey/afdelingen/{afdeling_id}/secties'
    )
    config.add_route(   
        'get_sectie_by_id_and_afdeling',
        '/capakey/afdelingen/{afdeling_id}/secties/{sectie_id}'
    )
    config.add_route(
        'list_percelen_by_sectie',
        '/capakey/afdelingen/{afdeling_id}/secties/{sectie_id}/percelen'
    )
    config.add_route(
        'get_perceel_by_sectie_and_id',
        '/capakey/afdelingen/{afdeling_id}/secties/{sectie_id}/percelen/{perceel_id1}/{perceel_id2}'
    )
    config.add_route(
        'get_perceel_by_capakey',
        '/capakey/percelen/{capakey1}/{capakey2}'
    )
    config.add_route('get_perceel_by_percid', '/capakey/percelen/{percid}')
    config.add_route('list_gewesten', '/crab/gewesten')
    config.add_route('get_gewest_by_id', '/crab/gewesten/{gewest_id}')
    config.add_route('list_gemeenten_crab', '/crab/gewesten/{gewest_id}/gemeenten')
    config.add_route('get_gemeente_crab', '/crab/gemeenten/{gemeente_id}')
    config.add_route('list_straten', '/crab/gemeenten/{gemeente_id}/straten')
    config.add_route('get_straat_by_id', '/crab/straten/{straat_id}')
    config.add_route('get_wegobject', '/crab/wegobjecten/{wegobject_id}')
    config.add_route('list_huisnummers', '/crab/straten/{straat_id}/huisnummers')
    config.add_route('get_huisnummer_by_straat_and_label', '/crab/straten/{straat_id}/huisnummers/{huisnummer_label}')
    config.add_route('get_huisnummer_by_id', '/crab/huisnummers/{huisnummer_id}')
    config.add_route('list_percelen', '/crab/huisnummers/{huisnummer_id}/percelen')
    config.add_route('get_perceel_by_id', '/crab/percelen/{perceel_id1}/{perceel_id2}')
    config.add_route('list_gebouwen', '/crab/huisnummers/{huisnummer_id}/gebouwen')
    config.add_route('get_gebouw_by_id', '/crab/gebouwen/{gebouw_id}')



# -*- coding: utf-8 -*-
'''
Routes for the CRAB views.

.. versionadded:: 0.1.0
'''
def includeme(config):
    config.add_route('list_gewesten', '/crab/gewesten')
    config.add_route('get_gewest_by_id', '/crab/gewesten/{gewest_id}')
    config.add_route('list_provincies', '/crab/gewesten/{gewest_id}/provincies')
    config.add_route('get_provincie', '/crab/provincies/{provincie_id}')
    config.add_route('list_gemeenten_by_provincie', '/crab/provincies/{provincie_id}/gemeenten')
    config.add_route('list_gemeenten_crab', '/crab/gewesten/{gewest_id}/gemeenten')
    config.add_route('get_gemeente_crab', '/crab/gemeenten/{gemeente_id}')
    config.add_route('list_straten', '/crab/gemeenten/{gemeente_id}/straten')
    config.add_route('get_straat_by_id', '/crab/straten/{straat_id}')
    config.add_route('get_wegobject', '/crab/wegobjecten/{wegobject_id}')
    config.add_route('list_huisnummers', '/crab/straten/{straat_id}/huisnummers')
    config.add_route('get_huisnummer_by_straat_and_label', '/crab/straten/{straat_id}/huisnummers/{huisnummer_label}')
    config.add_route('get_huisnummer_by_id', '/crab/huisnummers/{huisnummer_id}')
    config.add_route('list_percelen', '/crab/huisnummers/{huisnummer_id}/percelen')
    config.add_route('get_perceel_by_id', '/crab/percelen/{perceel_id1}/{perceel_id2}')
    config.add_route('list_gebouwen', '/crab/huisnummers/{huisnummer_id}/gebouwen')
    config.add_route('get_gebouw_by_id', '/crab/gebouwen/{gebouw_id}')



import os

from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.rst')).read()
CHANGES = open(os.path.join(here, 'CHANGES.rst')).read()

requires = [
    'pyramid',
    'crabpy>=0.4.1'
]

tests_requires = [
    'nose',
    'coverage',
    'webtest'
]

testing_extras = tests_requires + []

setup(name='crabpy_pyramid',
      version='0.1.1',
      description='crabpy_pyramid',
      long_description=README + '\n\n' + CHANGES,
      classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        "Framework :: Pyramid",
        "Topic :: Internet :: WWW/HTTP",
        "Intended Audience :: Developers",
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        ],
      author='Onroerend Erfgoed',
      author_email='ict@onroerenderfgoed.be',
      url='http://github.com/OnroerendErfgoed/crabpy_pyramid',
      keywords='web wsgi pyramid CRAB CAPAKEY AGIV',
      license='MIT',
      packages=find_packages(),
      include_package_data=True,
      zip_safe=False,
      test_suite='crabpy_pyramid',
      install_requires=requires,
      tests_require=tests_requires,
      entry_points="""\
      [paste.app_factory]
      main = crabpy_pyramid:main
      """,
      )



# -*- coding: utf-8 -*-
'''
Adapters to help render :mod:`crabpy.gateway.crab` objects to json.

.. versionadded:: 0.1.0
'''
from crabpy.gateway import crab

from pyramid.renderers import JSON

json_list_renderer = JSON()
json_item_renderer = JSON()

    
def list_gewesten_adapter(obj, request):
    '''
    Adapter for rendering a list of
    :class: `crabpy.gateway.crab.Gewest` to json.
    '''
    return {
        'id': obj.id,
        'naam': obj.naam
    }

def list_provincie_adapter(obj, request):
    '''
    Adapter for rendering a list of
    :class: `crabpy.gateway.crab.Provincie` to json.
    '''
    return {
        'niscode': obj.niscode,
        'naam': obj.naam,
        'gewest': {
            'id': obj.gewest.id,
            'naam': obj.gewest.naam
        }
    }

def list_gemeente_adapter(obj, request):
    '''
    Adapter for rendering a list of
    :class `crabpy.gateway.crab.Gemeenten` to json.
    '''
    return {
        'id': obj.id,
        'naam': obj.naam
    }

def list_straten_adapter(obj, request):
    '''
    Adapter for rendering a list of 
    :class: `crabpy.gateway.crab.Straat` to json.
    '''
    return {
        'id': obj.id,
        'label': obj.label,
        'status': {
            'id': obj.status.id,
            'naam': obj.status.naam,
            'definitie': obj.status.definitie
        },
    }
    
def list_huisnummers_adapter(obj, request):
    '''
    Adapter for rendering a list of
    :class: `crabpy.gateway.crab.Huisnummer` to json.
    '''
    return {
        'id':obj.id,
        'status': {
            'id': obj.status.id,
            'naam': obj.status.naam,
            'definitie': obj.status.definitie
        },
        'label':obj.huisnummer
    }

def list_percelen_adapter(obj, request):
    '''
    Adapter for rendering a list of 
    :class: `crabpy.gateway.crab.Perceel` to json.
    '''
    return {
        'id':obj.id
    }

def list_gebouwen_adapter(obj, request):
    '''
    Adapter for rendering a list of
    :class: `crabpy.gateway.crab.Gebouw` to json.
    '''
    return{
        'id': obj.id,
        'aard': {
            'id': obj.aard.id,
            'naam': obj.aard.naam,
            'definitie': obj.aard.definitie
        },
        'status': {
            'id': obj.status.id,
            'naam': obj.status.naam,
            'definitie': obj.status.definitie
        },
    }


json_list_renderer.add_adapter(crab.Gewest, list_gewesten_adapter)
json_list_renderer.add_adapter(crab.Provincie, list_provincie_adapter)
json_list_renderer.add_adapter(crab.Gemeente, list_gemeente_adapter)
json_list_renderer.add_adapter(crab.Straat, list_straten_adapter)
json_list_renderer.add_adapter(crab.Huisnummer, list_huisnummers_adapter)
json_list_renderer.add_adapter(crab.Perceel, list_percelen_adapter)
json_list_renderer.add_adapter(crab.Gebouw, list_gebouwen_adapter)


def item_gewest_adapter(obj, request):
    '''
    Adapter for rendering an object of
    :class:`crabpy.gateway.crab.Gewest` to json.
    '''
    return {
        'id': obj.id,
        'namen': obj._namen,
        'centroid': obj.centroid,
        'bounding_box': obj.bounding_box
    }
    
def item_provincie_adapter(obj, request):
    '''
    Adapter for rendering a object of
    :class: `crabpy.gateway.crab.Provincie` to json.
    '''
    return {
        'niscode': obj.niscode,
        'naam': obj.naam,
        'gewest': {
            'id': obj.gewest.id,
            'naam': obj.gewest.naam
        }
    }

def item_gemeente_adapter(obj, request):
    '''
    Adapter for rendering an object of
    :class:`crabpy.gateway.crab.Gemeente` to json.
    '''
    return {
        'id': obj.id,
        'naam': obj.naam,
        'centroid': obj.centroid,
        'bounding_box': obj.bounding_box,
        'metadata': {
            'begin_tijd': obj.metadata.begin_tijd,
            'begin_datum': obj.metadata.begin_datum,
            'begin_bewerking': {
                'id': obj.metadata.begin_bewerking.id,
                'naam': obj.metadata.begin_bewerking.naam,
                'definitie': obj.metadata.begin_bewerking.definitie
            },
            'begin_organisatie': {
                'id': obj.metadata.begin_organisatie.id,
                'naam': obj.metadata.begin_organisatie.naam,
                'definitie': obj.metadata.begin_organisatie.definitie
            }
        }
    }

def item_straat_adapter(obj, request):
    '''
    Adapter for rendering an object of
    :class:`crabpy.gateway.crab.Straat` to json.
    '''
    return {
        'id': obj.id,
        'label': obj.label,
        'namen': obj.namen,
        'status': {
            'id': obj.status.id,
            'naam': obj.status.naam,
            'definitie': obj.status.definitie
        },
        'taal': {
            'id': obj.taal.id,
            'naam': obj.taal.naam,
            'definitie': obj.taal.definitie
        },
        'metadata': {
            'begin_tijd': obj.metadata.begin_tijd,
            'begin_datum': obj.metadata.begin_datum,
            'begin_bewerking': {
                'id': obj.metadata.begin_bewerking.id,
                'naam': obj.metadata.begin_bewerking.naam,
                'definitie': obj.metadata.begin_bewerking.definitie
            },
            'begin_organisatie': {
                'id': obj.metadata.begin_organisatie.id,
                'naam': obj.metadata.begin_organisatie.naam,
                'definitie': obj.metadata.begin_organisatie.definitie
            }
        },
        'bounding_box': obj.bounding_box
    }

def item_huisnummer_adapter(obj, request):
    '''
    Adapter for rendering an object of 
    :class:`crabpy.gateway.crab.Huisnummer` to json.
    '''
    return {
        'id': obj.id,
        'huisnummer': obj.huisnummer,
        'status': {
            'id': obj.status.id,
            'naam': obj.status.naam,
            'definitie': obj.status.definitie
        },
        'metadata': {
            'begin_tijd': obj.metadata.begin_tijd,
            'begin_datum': obj.metadata.begin_datum,
            'begin_bewerking': {
                'id': obj.metadata.begin_bewerking.id,
                'naam': obj.metadata.begin_bewerking.naam,
                'definitie': obj.metadata.begin_bewerking.definitie
            },
            'begin_organisatie': {
                'id': obj.metadata.begin_organisatie.id,
                'naam': obj.metadata.begin_organisatie.naam,
                'definitie': obj.metadata.begin_organisatie.definitie
            }
        },
        'bounding_box': obj.bounding_box
    } 

def item_perceel_crab_adapter(obj, request):
    '''
    Adapter for rendering an object of
    :class:`crabpy.gateway.crab.Perceel` to json.
    '''
    return {
        'id': obj.id,
        'centroid': obj.centroid,
        'metadata': {
            'begin_tijd': obj.metadata.begin_tijd,
            'begin_datum': obj.metadata.begin_datum,
            'begin_bewerking': {
                'id': obj.metadata.begin_bewerking.id,
                'naam': obj.metadata.begin_bewerking.naam,
                'definitie': obj.metadata.begin_bewerking.definitie
            },
            'begin_organisatie': {
                'id': obj.metadata.begin_organisatie.id,
                'naam': obj.metadata.begin_organisatie.naam,
                'definitie': obj.metadata.begin_organisatie.definitie
            }
        }
    }

def item_gebouw_adapter(obj, request):
    '''
    Adapter for rendering an object of
    :class:`crabpy.gateway.crab.Gebouw` to json.
    '''
    return {
        'id': obj.id,
        'aard': {
            'id': obj.aard.id,
            'naam': obj.aard.naam,
            'definitie': obj.aard. definitie
        },
        'status': {
            'id': obj.status.id,
            'naam': obj.status.naam,
            'definitie': obj.status.definitie
        },
        'geometriemethode': {
            'id': obj.methode.id,
            'naam': obj.methode.naam,
            'definitie': obj.methode.definitie
        },
        'geometrie': obj.geometrie,
        'metadata': {
            'begin_tijd': obj.metadata.begin_tijd,
            'begin_datum': obj.metadata.begin_datum,
            'begin_bewerking': {
                'id': obj.metadata.begin_bewerking.id,
                'naam': obj.metadata.begin_bewerking.naam,
                'definitie': obj.metadata.begin_bewerking.definitie
            },
            'begin_organisatie': {
                'id': obj.metadata.begin_organisatie.id,
                'naam': obj.metadata.begin_organisatie.naam,
                'definitie': obj.metadata.begin_organisatie.definitie
            }
        }
    }
    
def item_wegobject_adapter(obj, request):
    '''
    Adapter for rendering a list of
    :class:`crabpy.gateway.Wegobject` to json.
    '''
    return {
        'id': obj.id,
        'aard': {
            'id': obj.aard.id,
            'naam': obj.aard.naam,
            'definitie': obj.aard.definitie
        },
        'centroid': obj.centroid,
        'bounding_box': obj.bounding_box,
        'metadata': {
            'begin_tijd': obj.metadata.begin_tijd,
            'begin_datum': obj.metadata.begin_datum,
            'begin_bewerking': {
                'id': obj.metadata.begin_bewerking.id,
                'naam': obj.metadata.begin_bewerking.naam,
                'definitie': obj.metadata.begin_bewerking.definitie
            },
            'begin_organisatie': {
                'id': obj.metadata.begin_organisatie.id,
                'naam': obj.metadata.begin_organisatie.naam,
                'definitie': obj.metadata.begin_organisatie.definitie
            }
        }
    }


json_item_renderer.add_adapter(crab.Gewest, item_gewest_adapter)
json_item_renderer.add_adapter(crab.Provincie, item_provincie_adapter)
json_item_renderer.add_adapter(crab.Gemeente, item_gemeente_adapter)
json_item_renderer.add_adapter(crab.Straat, item_straat_adapter)
json_item_renderer.add_adapter(crab.Huisnummer, item_huisnummer_adapter)
json_item_renderer.add_adapter(crab.Perceel, item_perceel_crab_adapter)
json_item_renderer.add_adapter(crab.Gebouw, item_gebouw_adapter)
json_item_renderer.add_adapter(crab.Wegobject, item_wegobject_adapter)
